==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerTrafficPolicyReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerTrafficPolicy resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerTrafficPolicyReference mailManagerTrafficPolicyReference = MailManagerTrafficPolicyReference.builder()
 *         .trafficPolicyId("trafficPolicyId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:04.002Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerTrafficPolicyReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerTrafficPolicyReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerTrafficPolicyReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The TrafficPolicyId of the MailManagerTrafficPolicy resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTrafficPolicyId();

    /**
     * @return a {@link Builder} of {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerTrafficPolicyReference> {
        java.lang.String trafficPolicyId;

        /**
         * Sets the value of {@link MailManagerTrafficPolicyReference#getTrafficPolicyId}
         * @param trafficPolicyId The TrafficPolicyId of the MailManagerTrafficPolicy resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficPolicyId(java.lang.String trafficPolicyId) {
            this.trafficPolicyId = trafficPolicyId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerTrafficPolicyReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerTrafficPolicyReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerTrafficPolicyReference {
        private final java.lang.String trafficPolicyId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.trafficPolicyId = software.amazon.jsii.Kernel.get(this, "trafficPolicyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.trafficPolicyId = java.util.Objects.requireNonNull(builder.trafficPolicyId, "trafficPolicyId is required");
        }

        @Override
        public final java.lang.String getTrafficPolicyId() {
            return this.trafficPolicyId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("trafficPolicyId", om.valueToTree(this.getTrafficPolicyId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerTrafficPolicyReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerTrafficPolicyReference.Jsii$Proxy that = (MailManagerTrafficPolicyReference.Jsii$Proxy) o;

            return this.trafficPolicyId.equals(that.trafficPolicyId);
        }

        @Override
        public final int hashCode() {
            int result = this.trafficPolicyId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerTrafficPolicyReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerTrafficPolicy resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerTrafficPolicyReference mailManagerTrafficPolicyReference = MailManagerTrafficPolicyReference.builder()
 *         .trafficPolicyArn("trafficPolicyArn")
 *         .trafficPolicyId("trafficPolicyId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.223Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerTrafficPolicyReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerTrafficPolicyReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerTrafficPolicyReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the MailManagerTrafficPolicy resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTrafficPolicyArn();

    /**
     * The TrafficPolicyId of the MailManagerTrafficPolicy resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTrafficPolicyId();

    /**
     * @return a {@link Builder} of {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerTrafficPolicyReference> {
        java.lang.String trafficPolicyArn;
        java.lang.String trafficPolicyId;

        /**
         * Sets the value of {@link MailManagerTrafficPolicyReference#getTrafficPolicyArn}
         * @param trafficPolicyArn The ARN of the MailManagerTrafficPolicy resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficPolicyArn(java.lang.String trafficPolicyArn) {
            this.trafficPolicyArn = trafficPolicyArn;
            return this;
        }

        /**
         * Sets the value of {@link MailManagerTrafficPolicyReference#getTrafficPolicyId}
         * @param trafficPolicyId The TrafficPolicyId of the MailManagerTrafficPolicy resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder trafficPolicyId(java.lang.String trafficPolicyId) {
            this.trafficPolicyId = trafficPolicyId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerTrafficPolicyReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerTrafficPolicyReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerTrafficPolicyReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerTrafficPolicyReference {
        private final java.lang.String trafficPolicyArn;
        private final java.lang.String trafficPolicyId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.trafficPolicyArn = software.amazon.jsii.Kernel.get(this, "trafficPolicyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.trafficPolicyId = software.amazon.jsii.Kernel.get(this, "trafficPolicyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.trafficPolicyArn = java.util.Objects.requireNonNull(builder.trafficPolicyArn, "trafficPolicyArn is required");
            this.trafficPolicyId = java.util.Objects.requireNonNull(builder.trafficPolicyId, "trafficPolicyId is required");
        }

        @Override
        public final java.lang.String getTrafficPolicyArn() {
            return this.trafficPolicyArn;
        }

        @Override
        public final java.lang.String getTrafficPolicyId() {
            return this.trafficPolicyId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("trafficPolicyArn", om.valueToTree(this.getTrafficPolicyArn()));
            data.set("trafficPolicyId", om.valueToTree(this.getTrafficPolicyId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerTrafficPolicyReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerTrafficPolicyReference.Jsii$Proxy that = (MailManagerTrafficPolicyReference.Jsii$Proxy) o;

            if (!trafficPolicyArn.equals(that.trafficPolicyArn)) return false;
            return this.trafficPolicyId.equals(that.trafficPolicyId);
        }

        @Override
        public final int hashCode() {
            int result = this.trafficPolicyArn.hashCode();
            result = 31 * result + (this.trafficPolicyId.hashCode());
            return result;
        }
    }
}
